@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import sys
 from typing import Callable
 
 __all__ = ('SUPPORTED',)
@@ -13,8 +14,10 @@ try:
 
     def get_service_by_name(service: str) -> Callable:
         return server.tss.translators_dict[service]
-except ImportError:
+except Exception as e:
     SUPPORTED = False
+    if not isinstance(e, ImportError):
+        sys.stderr.write(str(e))
 else:
     SUPPORTED = True
     __all__ += ('translators', 'SERVICES', 'get_service_by_name', 'subs_translate')
